@@ -249,3 +249,21 @@ class Connector:
             for record, primary_key in zip(data, pk):
                 updated.append(self.update(model, record, primary_key, pk_column))
             return updated
+
+    def execute_raw_query(self, query, is_select=False):
+        """
+        This method is used to execute raw sql query and return response. This is ideal for update, delete and add
+        operations
+        :param is_select: Mark this parameter as true if you want the function to return list of items as responses
+        :param query: Raw sql query to be applied
+        :return: return response
+        """
+
+        if self.connection is not None:
+            cursor = self.connection.cursor()
+            response = cursor.execute(query)
+            if is_select:
+                records = cursor.fetchall()
+                return response, records
+            self.connection.commit()
+            return response
